@@ -1,5 +1,5 @@
 __doc__ = '''Calendar tag'''
-__version__='1.0.10'
+__version__='1.0.12'
 
 
 from string import capitalize, join, replace, split
@@ -69,6 +69,7 @@ daynames = {'ca': ('Du', 'Dll', 'Dm', 'Dx', 'Dj', 'Dv', 'Ds'),
             'es': ('D', 'L', 'M', 'Mi', 'J', 'V', 'S'),
             'fi': ('Su', 'Ma', 'Ti', 'Ke', 'To', 'Pe', 'La'),
             'fr': ('D', 'L', 'M', 'M', 'J', 'V', 'S'),
+            'ro': ('D', 'L', 'M', 'M', 'J', 'V', 'S'),
             'it': ('Do', 'Lu', 'Ma', 'Me', 'Gio', 'Ve', 'Sa'),
             'ja': ('', '', '', '', '', '', ''),
             'no': 'SMTOTFL',
@@ -84,6 +85,7 @@ translations = {
               'es': 'D&iacute;a',
               'fi': 'Piv',
               'fr': 'Jour',
+              'ro': 'Zi',
               'it': 'Giorno',
               'ja': '',
               'no': 'Dag',
@@ -97,6 +99,7 @@ translations = {
               'es': 'Semana',
               'fi': 'Viikko',
               'fr': 'Semaine',
+              'ro': 'Saptam&icirc;na',
               'it': 'Settimana',
               'ja': '',
               'no': 'Uke',
@@ -110,6 +113,7 @@ translations = {
               'es': 'Mes',
               'fi': 'Kuukausi',
               'fr': 'Mois',
+              'ro': 'Luna',
               'it': 'Mese',
               'ja': '',
               'no': 'M&aring;ned',
@@ -123,6 +127,7 @@ translations = {
               'es': 'Ao',
               'fi': 'Vuosi',
               'fr': 'Ann&eacute;e',
+              'ro': 'Anul',
               'it': 'Anno',
               'ja': 'ǯ',
               'no': '&Aring;r',
@@ -136,6 +141,7 @@ translations = {
                        'es': 'Semana previa',
                        'fi': 'Edellinen viikko',
                        'fr': 'Semaine Pr&eacute;c&eacute;dente',
+                       'ro': 'Saptam&icirc;na trecuta',
                        'it': 'Settimana precedente',
                        'ja': '轵',
                        'no': 'Forrige Uke',
@@ -149,6 +155,7 @@ translations = {
                        'es': 'Semana siguiente',
                        'fi': 'Seuraava viikko',
                        'fr': 'Semaine Suivante',
+                       'ro': 'Saptam&icirc;na viitoare',
                        'it': 'Settimana successiva',
                        'ja': '轵',
                        'no': 'Neste Uke',
@@ -162,6 +169,7 @@ translations = {
                        'es': 'Mes previo',
                        'fi': 'Edellinen kuukausi',
                        'fr': 'Mois Pr&eacute;c&eacute;dent',
+                       'ro': 'Luna trecuta',
                        'it': 'Mese precedente',
                        'ja': '',
                        'no': 'Forrige M&aring;ned',
@@ -175,6 +183,7 @@ translations = {
                        'es': 'Mes siguiente',
                        'fi': 'Seuraava kuukausi',
                        'fr': 'Mois Suivant',
+                       'ro': 'Luna viitoare',
                        'it': 'Mese successivo',
                        'ja': '',
                        'no': 'Neste M&aring;ned',
@@ -188,6 +197,7 @@ translations = {
                        'es': 'A&ntilde;o previo',
                        'fi': 'Edellinen vuosi',
                        'fr': 'Ann&eacute;e Pr&eacute;c&eacute;dente',
+                       'ro': 'Anul trecut',
                        'it': 'Anno precedente',
                        'ja': 'ǯ',
                        'no': 'Forrige &Aring;r',
@@ -201,6 +211,7 @@ translations = {
                        'es': 'A&ntilde;o siguiente',
                        'fi': 'Seuraava vuosi',
                        'fr': 'Ann&eacute;e Suivante',
+                       'ro': 'Anul viitor',
                        'it': 'Anno successivo',
                        'ja': 'ǯ',
                        'no': 'Neste &Aring;r',
@@ -214,6 +225,7 @@ translations = {
                   'es': 'Enero',
                   'fi': 'Tammikuu',
                   'fr': 'Janvier',
+                  'ro': 'Ianuarie',
                   'it': 'Gennaio',
                   'ja': '1',
                   'no': 'Januar',
@@ -227,6 +239,7 @@ translations = {
                   'es': 'Febrero',
                   'fi': 'Helmikuu',
                   'fr': 'F&eacute;vrier',
+                  'ro': 'Februarie',
                   'it': 'Febbraio',
                   'ja': '2',
                   'no': 'Februar',
@@ -240,6 +253,7 @@ translations = {
                   'es': 'Marzo',
                   'fi': 'Maaliskuu',
                   'fr': 'Mars',
+                  'ro': 'Martie',
                   'it': 'Marzo',
                   'ja': '3',
                   'no': 'Mars',
@@ -253,6 +267,7 @@ translations = {
                   'es': 'Abril',
                   'fi': 'Huhtikuu',
                   'fr': 'Avril',
+                  'ro': 'Aprilie',
                   'it': 'Aprile',
                   'ja': '4',
                   'no': 'April',
@@ -266,6 +281,7 @@ translations = {
                   'es': 'Mayo',
                   'fi': 'Toukokuu',
                   'fr': 'Mai',
+                  'ro': 'Mai',
                   'it': 'Maggio',
                   'ja': '5',
                   'no': 'Mai',
@@ -279,6 +295,7 @@ translations = {
                   'es': 'Junio',
                   'fi': 'Keskuu',
                   'fr': 'Juin',
+                  'ro': 'Iunie',
                   'it': 'Giugno',
                   'ja': '6',
                   'no': 'Juni',
@@ -292,6 +309,7 @@ translations = {
                   'es': 'Julio',
                   'fi': 'Heinkuu',
                   'fr': 'Juillet',
+                  'ro': 'Iulie',
                   'it': 'Luglio',
                   'ja': '7',
                   'no': 'Juli',
@@ -305,6 +323,7 @@ translations = {
                   'es': 'Agosto',
                   'fi': 'Elokuu',
                   'fr': 'Ao&ucirc;t',
+                  'ro': 'August',
                   'it': 'Agosto',
                   'ja': '8',
                   'no': 'August',
@@ -318,6 +337,7 @@ translations = {
                   'es': 'Septiembre',
                   'fi': 'Syyskuu',
                   'fr': 'Septembre',
+                  'ro': 'Septembrie',
                   'it': 'Settembre',
                   'ja': '9',
                   'no': 'September',
@@ -331,6 +351,7 @@ translations = {
                   'es': 'Octubre',
                   'fi': 'Lokakuu',
                   'fr': 'Octobre',
+                  'ro': 'Octombrie',
                   'it': 'Ottobre',
                   'ja': '10',
                   'no': 'Oktober',
@@ -344,6 +365,7 @@ translations = {
                   'es': 'Noviembre',
                   'fi': 'Marraskuu',
                   'fr': 'Novembre',
+                  'ro': 'Noiembrie',
                   'it': 'Novembre',
                   'ja': '11',
                   'no': 'November',
@@ -357,6 +379,7 @@ translations = {
                   'es': 'Diciembre',
                   'fi': 'Joulukuu',
                   'fr': 'D&eacute;cembre',
+                  'ro': 'Decembrie',
                   'it': 'Dicembre',
                   'ja': '12',
                   'no': 'Desember',
@@ -370,6 +393,7 @@ translations = {
             'es': 'Ene',
             'fi': 'Tam',
             'fr': 'Jan',
+            'ro': 'Ian',
             'it': 'Gen',
             'ja': '1',
             'no': 'Jan',
@@ -383,6 +407,7 @@ translations = {
             'es': 'Feb',
             'fi': 'Hel',
             'fr': 'F&eacute;v',
+            'ro': 'Feb',
             'it': 'Feb',
             'ja': '2',
             'no': 'Feb',
@@ -396,6 +421,7 @@ translations = {
             'es': 'Mar',
             'fi': 'Maa',
             'fr': 'Mar',
+            'ro': 'Mar',
             'it': 'Mar',
             'ja': '3',
             'no': 'Mar',
@@ -409,6 +435,7 @@ translations = {
             'es': 'Abr',
             'fi': 'Huh',
             'fr': 'Avr',
+            'ro': 'Apr',
             'it': 'Apr',
             'ja': '4',
             'no': 'Apr',
@@ -422,6 +449,7 @@ translations = {
             'es': 'May',
             'fi': 'Tou',
             'fr': 'Mai',
+            'ro': 'Mai',
             'it': 'Mag',
             'ja': '5',
             'no': 'Mai',
@@ -435,6 +463,7 @@ translations = {
             'es': 'Jun',
             'fi': 'Kes',
             'fr': 'Juin',
+            'ro': 'Iun',
             'it': 'Giu',
             'ja': '6',
             'no': 'Jun',
@@ -448,6 +477,7 @@ translations = {
             'es': 'Jul',
             'fi': 'Hei',
             'fr': 'Juil',
+            'ro': 'Iul',
             'it': 'Lug',
             'ja': '7',
             'no': 'Jul',
@@ -461,6 +491,7 @@ translations = {
             'es': 'Ago',
             'fi': 'Elo',
             'fr': 'Ao&ucirc;',
+            'ro': 'Aug',
             'it': 'Ago',
             'ja': '8',
             'no': 'Aug',
@@ -474,6 +505,7 @@ translations = {
             'es': 'Sep',
             'fi': 'Syy',
             'fr': 'Sep',
+            'ro': 'Sep',
             'it': 'Set',
             'ja': '9',
             'no': 'Sep',
@@ -487,6 +519,7 @@ translations = {
             'es': 'Oct',
             'fi': 'Lok',
             'fr': 'Oct',
+            'ro': 'Oct',
             'it': 'Ott',
             'ja': '10',
             'no': 'Okt',
@@ -500,6 +533,7 @@ translations = {
             'es': 'Nov',
             'fi': 'Mar',
             'fr': 'Nov',
+            'ro': 'Nov',
             'it': 'Nov',
             'ja': '11',
             'no': 'Nov',
@@ -513,6 +547,7 @@ translations = {
             'es': 'Dic',
             'fi': 'Jou',
             'fr': 'D&eacute;c',
+            'ro': 'Dec',
             'it': 'Dec',
             'ja': '12',
             'no': 'Des',
@@ -526,6 +561,7 @@ translations = {
 ##                  'es': 'Domingo',
 ##                  'fi': 'Sunnuntai',
 ##                  'fr': 'Dimanche',
+##                  'ro': 'Duminica',
 ##                  'it': '',
 ##                  'no': 'S&oslash;ndag',
 ##                  'pt': 'Domingo',
@@ -537,6 +573,7 @@ translations = {
 ##                  'es': 'Lunes',
 ##                  'fi': 'Maanantai',
 ##                  'fr': 'Lundi',
+##                  'ro': 'Luni',
 ##                  'it': '',
 ##                  'no': 'Mandag',
 ##                  'pt': 'Segunda',
@@ -548,6 +585,7 @@ translations = {
 ##                  'es': 'Martes',
 ##                  'fi': 'Tiistai',
 ##                  'fr': 'Mardi',
+##                  'ro': 'Marti',
 ##                  'it': '',
 ##                  'no': 'Tirsdag',
 ##                  'pt': 'Tera',
@@ -559,6 +597,7 @@ translations = {
 ##                  'es': 'Mi&eacute;rcoles',
 ##                  'fi': 'Keskiviikko',
 ##                  'fr': 'Mercredi',
+##                  'ro': 'Miercuri',
 ##                  'it': '',
 ##                  'no': 'Onsdag',
 ##                  'pt': 'Quarta',
@@ -570,6 +609,7 @@ translations = {
 ##                  'es': 'Jueves',
 ##                  'fi': 'Torstai',
 ##                  'fr': 'Jeudi',
+##                  'ro': 'Joi',
 ##                  'it': '',
 ##                  'no': 'Torsdag',
 ##                  'pt': 'Quinta',
@@ -581,6 +621,7 @@ translations = {
 ##                  'es': 'Viernes',
 ##                  'fi': 'Perjantai',
 ##                  'fr': 'Vendredi',
+##                  'ro': 'Vineri',
 ##                  'it': '',
 ##                  'no': 'Fredag',
 ##                  'pt': 'Sexta',
@@ -592,6 +633,7 @@ translations = {
 ##                  'es': 'S&aacute;bado',
 ##                  'fi': 'Lauantai',
 ##                  'fr': 'Samedi',
+##                  'ro': 'S&icirc;mbata',
 ##                  'it': '',
 ##                  'no': 'L&oslash;rdag',
 ##                  'pt': 'Sbado',
@@ -1030,4 +1072,3 @@ class CalendarTag:
 # Install the calendar tag globally
 
 String.commands['calendar'] = CalendarTag
-
